<?xml version="1.0" encoding="UTF-8" ?>
<!-- footer-header.xsl
 | DITA templates for running header and footer
 |
 | Copyright IBM Corporation, 2007
-->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                xmlns:xt="http://www.jclark.com/xt"
                xmlns:java="idwb.FormatDate"
                extension-element-prefixes="saxon xt">

<!-- stylesheet imports -->

<!-- build and production values -->
<xsl:param name="entity-file">share\entities.dita</xsl:param>
<xsl:param name="PATH2PROJ">..\</xsl:param>
<xsl:param name="WORKDIR"/>
<xsl:param name="FILENAME"/>
<!-- user.input.dir -->
<xsl:param name="MAPTEMPDIR" />
<xsl:param name="OUTEXT"/>

<!-- Case definitions to translate to lowercase -->
<xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
<xsl:variable name="lowercase" select="'abcdefghijklmnopqrstuvwxyz'"/>

<xsl:variable name="TOPICTYPE">
	<!-- What is the type of this topic? Task, Concept, Reference, ...? -->
		<xsl:choose>
			<xsl:when test="name(/*)='dita'">
				<xsl:value-of select="name(/*/*[1])"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="name(/*)"/>
			</xsl:otherwise>
		</xsl:choose>
</xsl:variable>

<xsl:variable name="BUILDSTRINGSFILE">
	<!-- What is the type of this topic? Task, Concept, Reference, ...? -->
		<xsl:choose>
			<xsl:when test="string-length($FTR)>0">
				<xsl:value-of select="$FTR"/>
			</xsl:when>
			<xsl:when test="string-length($HDR)>0">
				<xsl:value-of select="$HDR"/>
			</xsl:when>
			<xsl:otherwise>
	<xsl:call-template name="output-message">
          <xsl:with-param name="msg">FOOTER_HEADER.XSL. 
		  	You must specify a build options file for either the IDWB optiocs /FTR or /HDR (or both)
		  </xsl:with-param>
          <xsl:with-param name="msgnum">999</xsl:with-param>
          <xsl:with-param name="msgsev">W</xsl:with-param>
          </xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
</xsl:variable>

<xsl:variable name="inputmap" select="document('dita.xml.properties',document(''))//entry[@key='user.input.file']/text()"/>

<!-- Get plugin type for build -->
<xsl:variable name="maptype"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'plugintype'"/></xsl:call-template></xsl:variable>

<!-- xsl:value-of select="document(concat($PATH2PROJ,$inputmap), /)//plugin/@type"/>-->

<xsl:variable name="inputdir">
        <xsl:call-template name="replacestring">
          <xsl:with-param name="text" select="document('dita.xml.properties',document(''))//entry[@key='user.input.dir']/text()"/>
          <xsl:with-param name="string" select="'\\'"/>
          <xsl:with-param name="with" select="'\'"/>
        </xsl:call-template>
</xsl:variable>

<xsl:variable name="home_id"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'home_id'"/></xsl:call-template></xsl:variable>
<xsl:variable name="home_class"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'home_class'"/></xsl:call-template></xsl:variable>


<xsl:template name="processHDR">

  <!-- Add user's running header if requested to by IDWB /HDR option
		- If specifies an XML file, generate header using options from that file
		- Otherwise, assume an xhtml extract and copy that (as in default IDWB) -->
  <xsl:if test="string-length($HDR)>0">

	<xsl:choose>
	  <!-- For XML HDR file, generate standard header -->
	  <xsl:when test="contains($HDR,'.xml')">

		<!-- Generate running header if NOT the IC home page -->
		<xsl:if test="not(@id=$home_id or @outputclass=$home_class)">

		<xsl:comment> Start running header </xsl:comment><xsl:value-of select="$newline"/>
		<xsl:choose>
		<!-- If plug-in being built is generic (shared by multiple products), do not add product-specific header -->
		<xsl:when test="$maptype = 'generic'">
			<xsl:call-template name="brandicon"/><xsl:value-of select="$newline"/>
		</xsl:when>
		<xsl:otherwise>
			<div class="runningheader"> <xsl:value-of select="$newline"/>
			<xsl:call-template name="brandicon"/><xsl:value-of select="$newline"/>
			<span><strong><!-- Use productshortname without brand name prefix - as provided by brand icon --> <xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'productshortname'"/><xsl:with-param name="optionFile" select="$HDR"/></xsl:call-template></strong><xsl:text> </xsl:text><xsl:value-of select="$newline"/>
			<!-- Optional operating systems -->
			<xsl:variable name="os"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'operatingsystems'"/><xsl:with-param name="optionFile" select="$HDR"/></xsl:call-template></xsl:variable>
			<xsl:choose>
			<xsl:when test="string-length($os) > 0">
				<xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'operatingsystems'"/></xsl:call-template><xsl:text>: </xsl:text>
				<strong><xsl:value-of select="$os"/></strong><xsl:value-of select="$newline"/>
			</xsl:when>
			<xsl:otherwise><xsl:comment>Optional operating systems not added because build operatingsystems option not set.</xsl:comment></xsl:otherwise>
			</xsl:choose>
		</span>
		</div>
		</xsl:otherwise>
		</xsl:choose>
		<xsl:comment> End running header </xsl:comment>
		<br /><hr align="left" /><xsl:value-of select="$newline"/>
		<xsl:value-of select="$newline"/>

		</xsl:if>

	</xsl:when>
	  <!-- Add user's running header XHTML code snippet if requested to -->
	<xsl:otherwise>
	    <xsl:copy-of select="document($HDR)"/>
	    <xsl:value-of select="$newline"/>
	</xsl:otherwise>
	</xsl:choose>

  </xsl:if>

</xsl:template>


<xsl:template name="processFTR">
  <!-- Add user's running footer if requested to by IDWB /FTR option
		- If specifies an XML file, generate footer using options from that file
		- Otherwise, assume an xhtml extract and copy that (as in default IDWB) -->

	<!-- xsl:call-template name="output-message">
          <xsl:with-param name="msg">FOOTER_HEADER.XSL. 
		  	FTR = <xsl:value-of select="$FTR"/>
		  	WORKDIR = <xsl:value-of select="$WORKDIR"/>
			FILENAME = <xsl:value-of select="$FILENAME"/>
			inputmap = <xsl:value-of select="$inputmap"/>
			inputdir = <xsl:value-of select="$inputdir" />
		  </xsl:with-param>
          <xsl:with-param name="msgnum">999</xsl:with-param>
          <xsl:with-param name="msgsev">I</xsl:with-param>
          </xsl:call-template-->
		
  <xsl:if test="string-length($FTR)>0">

	<xsl:choose>
	  <!-- For XML FTR file, generate standard footer -->
	  <xsl:when test="contains($FTR,'.xml')">

	<xsl:variable name="COMMONFEEDBACKPLUGIN"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'commonfeedbackplugin'"/></xsl:call-template></xsl:variable>

	<xsl:comment> Start running footer </xsl:comment><xsl:value-of select="$newline"/>
	<div class="runningfooter"> <xsl:value-of select="$newline"/>
	<br /><xsl:value-of select="$newline"/>

	<!-- Option to show the topic type -->	
	<xsl:variable name="showtypeoption"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'showtype'"/></xsl:call-template></xsl:variable>
	<xsl:variable name="topictypestring"><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="concat($TOPICTYPE,'topic')"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="translate($showtypeoption,$uppercase,$lowercase)='yes'">
			<span><img style="border:0" alt="{$topictypestring}" title="{$topictypestring}" src="{$PATH2PROJ}info/{$TOPICTYPE}_obj.gif" /><xsl:text> </xsl:text>
			<strong><xsl:comment> TOPICTYPE </xsl:comment><xsl:value-of select="$topictypestring"/></strong></span><xsl:value-of select="$newline"/>
		</xsl:when>
		<xsl:otherwise><xsl:comment>Optional topic type not added because build showtype option not set to "yes".</xsl:comment></xsl:otherwise>
	</xsl:choose>

	<!-- TBD:  Add link to PDF that contains this topic -->
	<!-- Option to show the PDF link -->	
	<xsl:variable name="showtopicinpdf"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'showtopicinpdf'"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="translate($showtopicinpdf,$uppercase,$lowercase)='yes'">

	<xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'topicinpdf'"/></xsl:call-template><xsl:text>: </xsl:text>
		</xsl:when>
		<xsl:otherwise><xsl:comment>Optional PDF link not added because build showtopicinpdf option not set to "yes".</xsl:comment></xsl:otherwise>
	</xsl:choose>
	
	<br /><hr align="left" />
	<!-- Add "Terms of use" link only for bookshelf homepage for corporate legal and collateral guidelines.  
		See http://ausgsa.ibm.com/projects/c/common_collateral/SWG_instructions/header_footer_guidelines.html -->
	<xsl:if test="@id=$home_id or @outputclass=$home_class">
		<!-- Option for own href to Terms of Use page -->	
		<xsl:variable name="termsofuse_href"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'termsofuse_href'"/></xsl:call-template></xsl:variable>
	   <a>
	   	<xsl:attribute name="href">
			<xsl:choose>
				<!-- When termsofuse_href str set to http:// URL -->
				<xsl:when test="contains($termsofuse_href,'http:')"><xsl:value-of select="$termsofuse_href" /></xsl:when>
				<!-- When termsofuse_href str set to local URL (relative path from root of plug-in to a file) -->
				<xsl:when test="string-length($termsofuse_href)>0"><xsl:value-of select="concat($PATH2PROJ,$termsofuse_href)" /></xsl:when>
				<!-- Default if termsofuse_href str not set -->
				<xsl:otherwise><xsl:value-of select="concat($PATH2PROJ,'../',$COMMONFEEDBACKPLUGIN,'/info/termsofuse.html')" /></xsl:otherwise>
			</xsl:choose>
	   	</xsl:attribute>
		<strong><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'termsofuse'"/></xsl:call-template></strong></a> | 
	</xsl:if>

	<!-- Option for own href for Feedback page -->	
	<xsl:variable name="feedback_href"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'feedback_href'"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="string-length($feedback_href)>0">
			<xsl:value-of select="$newline"/>
			<a href="{concat($PATH2PROJ,$feedback_href)}"><strong><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'feedback'"/></xsl:call-template></strong></a>
		</xsl:when>
		<xsl:otherwise>
			<xsl:element name="script"><!-- Script to define the 'global' variables -->
				<xsl:attribute name="type">text/javascript</xsl:attribute>
			<xsl:text>var mDivision = "</xsl:text><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'division'"/></xsl:call-template><xsl:text>"</xsl:text><xsl:value-of select="$newline"/>
			<xsl:text>var mToList = "</xsl:text><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'sendfeedbackto'"/></xsl:call-template><xsl:text>"</xsl:text><xsl:value-of select="$newline"/>
			<xsl:text>var mProductName = "</xsl:text><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'productname'"/></xsl:call-template><xsl:text>"</xsl:text><xsl:value-of select="$newline"/>
			<xsl:text>var mProductVersion = "</xsl:text><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'productversion'"/></xsl:call-template><xsl:text>"</xsl:text><xsl:value-of select="$newline"/>
			</xsl:element>
			<xsl:value-of select="$newline"/>
			<xsl:element name="script"><!-- Script for common RCF feedback mechanism -->
				<xsl:attribute name="type" select="'text/javascript'"/>
				<xsl:attribute name="src" select="concat($PATH2PROJ,'../',$COMMONFEEDBACKPLUGIN,'/info/srcf.js')"/>
			<xsl:text> <!-- Need xsl:text to preserve /script tag, otherwise the script does not work --> </xsl:text>
			</xsl:element>
			<xsl:value-of select="$newline"/>
			<a href="javascript:ibm_id_form()"><strong><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'feedback'"/></xsl:call-template></strong></a>
		</xsl:otherwise>
	</xsl:choose>
	<br /><xsl:value-of select="$newline"/>

	<!-- Option to show Last updated date -->	
	<xsl:variable name="showlastdateoption"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'showlastdate'"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="translate($showlastdateoption,$uppercase,$lowercase)='yes'">
			 <br/><br/><img style="border:0; valign:middle" src="{$PATH2PROJ}info/timestamp.gif" >
			<xsl:attribute name="alt"><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'timestampicon'"/></xsl:call-template></xsl:attribute>
			<xsl:attribute name="title"><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'timestampicon'"/></xsl:call-template></xsl:attribute>
			</img><xsl:text> </xsl:text><span><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'lastupdated'"/></xsl:call-template><xsl:text>: </xsl:text><!-- UPDATED -->
			<!-- Get text string of date.  If not empty then use for Last updated date for publish html; otherwise use java date. -->
			<xsl:variable name="textdate-time"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'last_date'"/></xsl:call-template></xsl:variable>
			<!-- Call java writelocaldate class to get current date in build machine's locale -->
			<xsl:variable name="javadate-time">
			  <xsl:choose>
				 <xsl:when test="string-length($textdate-time) > 0"><xsl:value-of select="$textdate-time"/></xsl:when>
			     <xsl:otherwise><xsl:value-of select="document('date.xml',document(''))//entry[@key='build.date']/text()"/></xsl:otherwise>
			     <!-- xsl:otherwise><xsl:value-of select="document('date.xml')//entry[@key='build.date']"/></xsl:otherwise -->
			  </xsl:choose>
			</xsl:variable>
			<xsl:value-of select="$javadate-time"/>
			</span><br /><xsl:value-of select="$newline"/>
		</xsl:when>
		<xsl:otherwise><xsl:comment>Optional Last updated date not added because build showlastdate option not set to "yes".</xsl:comment></xsl:otherwise>
	</xsl:choose>

	<!-- Option to show topic URL -->	
	<xsl:variable name="showtopicurloption"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'showtopicurl'"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="translate($showtopicurloption,$uppercase,$lowercase)='yes'">
			<xsl:value-of select="$newline"/>
			<span><!--xsl:call-template name="path2plugin"/>/<xsl:call-template name="pluginfile"/-->
			<!-- All script tags need type="text/javascript" to pass CHKPII -->
			<script type="text/javascript">
			    // Create variable is_input to see if there is a ? in the url
			       var is_input = document.URL.indexOf('?');
			    // Check the position of the ? in the url
    		    if (is_input != -1) { 
		            // Create variable from ? in the url to the end of the string
		            addr_str = document.URL.substring(0, document.URL.indexOf('?'));
		            document.write(addr_str)
		        }
		        else
		            document.write(document.location.toString());
			</script>
			</span><br /><br /><xsl:value-of select="$newline"/>
			<span style="visibility:hidden"><xsl:call-template name="path2plugin"/><xsl:call-template name="pluginfile"/></span><br /><xsl:value-of select="$newline"/>
		</xsl:when>
		<xsl:otherwise><xsl:comment>Optional topic URL not added because build showtopicurl option not set to "yes".</xsl:comment></xsl:otherwise>
	</xsl:choose>

	<!-- Add copyright line and Eclipse attribution only for bookshelf homepage for corporate legal and collateral guidelines.  
		See http://ausgsa.ibm.com/projects/c/common_collateral/SWG_instructions/header_footer_guidelines.html -->
	<xsl:if test="@id=$home_id or @outputclass=$home_class">
		<span><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'copyrightline'"/></xsl:call-template><br /></span><xsl:value-of select="$newline"/>
		<span><xsl:call-template name="getCommonString"><xsl:with-param name="stringName" select="'eclipseline'"/></xsl:call-template></span><xsl:value-of select="$newline"/>
	</xsl:if>
	<xsl:value-of select="$newline"/>
	</div><xsl:value-of select="$newline"/>
	<xsl:comment> End running footer </xsl:comment>

	</xsl:when>
	  <!-- Add user's running footer XHTML code snippet if requested to -->
	<xsl:otherwise>
	    <xsl:copy-of select="document($FTR)"/>
	    <xsl:value-of select="$newline"/>
	</xsl:otherwise>
	</xsl:choose>

  </xsl:if>

</xsl:template>


<!-- Add xhtml for brand icon, based on brand build option -->
<xsl:template name="brandicon">
	<xsl:variable name="brandoption"><xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'brand'"/><xsl:with-param name="optionFile" select="$HDR"/></xsl:call-template></xsl:variable>
	<xsl:choose>
		<xsl:when test="translate($brandoption,$uppercase,$lowercase)='lotus'"><img style="border:0; valign:middle" alt="Lotus" src="{$PATH2PROJ}info/IC-lotus-sm.gif" /></xsl:when>
		<xsl:when test="translate($brandoption,$uppercase,$lowercase)='rational'"><img style="border:0; valign:middle" alt="Rational" src="{$PATH2PROJ}info/IC-rtl-sm.gif" /></xsl:when>
		<xsl:when test="translate($brandoption,$uppercase,$lowercase)='tivoli'"><img style="border:0; valign:middle" alt="Tivoli" src="{$PATH2PROJ}info/IC-tiv-sm.gif" /></xsl:when>
		<xsl:when test="translate($brandoption,$uppercase,$lowercase)='websphere'"><img style="border:0; valign:middle" alt="WebSphere" src="{$PATH2PROJ}info/IC-ws-sm.gif" /></xsl:when>
		<xsl:otherwise><!-- Brand option not specified.  Don't add brand icon --></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Get plug-id from DITA plug-in map, otherwise from pluginid build option -->
<xsl:template name="pluginid">
<xsl:choose>
<xsl:when test="boolean(document(concat($PATH2PROJ,$inputmap), /)//plugin/@id)">
<!-- Get pluginid from DITA plugin map -->
<xsl:value-of select="document(concat($PATH2PROJ,$inputmap), /)//plugin/@id"/>
</xsl:when>
<xsl:otherwise>
<!-- Get pluginid from ordinary DITA map -->
      <xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'pluginid'"/></xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="path2plugin">
      <xsl:call-template name="getBuildString"><xsl:with-param name="stringName" select="'path2plugin'"/></xsl:call-template>
</xsl:template>

<xsl:template name="pluginfile">
<xsl:call-template name="pluginid"/>/<xsl:value-of select="substring-after($WORKDIR,translate($inputdir,'/\','\/'))"/><xsl:value-of select="substring-before($FILENAME,'.')"/>.<xsl:value-of select="$OUTEXT"/>
</xsl:template>

<xsl:template name="getBuildString">
    <xsl:param name="stringName"/>
	<xsl:param name="optionFile" select="$BUILDSTRINGSFILE"/>
	
   <!-- Get the string -->
    <xsl:variable name="str" select="document($optionFile,document(''))//str[@name=$stringName]"/>

    <xsl:choose>
        <!-- If the string was found, use it. Cannot test $str, because value could be empty. -->
        <xsl:when test="document($optionFile,document(''))//str[@name=$stringName]">
            <xsl:value-of select="$str"/>
        </xsl:when>
        <!-- String not found. -->
        <xsl:otherwise>
            <xsl:value-of select="$stringName"/>
            <xsl:call-template name="output-message">
                <xsl:with-param name="msg">No string named '<xsl:value-of select="$stringName"/>' was found in '<xsl:value-of select="$optionFile"/>'. Using default value.</xsl:with-param>
                <xsl:with-param name="msgnum">008</xsl:with-param>
                <xsl:with-param name="msgsev">I</xsl:with-param>
            </xsl:call-template>
		   <!-- Get the default string -->
		    <xsl:value-of select="document($optionFile,document('footer-header.options.xml'))//str[@name=$stringName]"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<!-- Template to replace one string with another, eg to handle '\\' to '\' in path name -->
<xsl:template name="replacestring">
    <xsl:param name="text"/>
    <xsl:param name="string"/>
    <xsl:param name="with"/>
    <xsl:choose>
      <xsl:when test="contains($text,$string)">
        <xsl:value-of select="substring-before($text,$string)"/>
        <xsl:value-of select="$with"/>
        <xsl:call-template name="replacestring">
          <xsl:with-param name="text" select="substring-after($text,$string)"/>
          <xsl:with-param name="string" select="$string"/>
          <xsl:with-param name="with" select="$with"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

<xsl:template name="getCommonString">
    <xsl:param name="stringName"/>
    <xsl:param name="stringFileList">strings/strings.xml</xsl:param>
    <xsl:variable name="ancestorlang">  <!-- Get the current language -->
      <xsl:choose>
        <!-- When transforming a dita type file, get xml:lang of the child type -->
        <xsl:when test="self::dita">
          <xsl:for-each select="*[1]"><xsl:call-template name="getLowerCaseLang"/></xsl:for-each>
        </xsl:when>
        <xsl:otherwise><xsl:call-template name="getLowerCaseLang"/></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!-- Determine which file holds translations for the current language -->
    <xsl:variable name="stringfile">
        <xsl:value-of select="document($stringFileList)/*/lang[@xml:lang=$ancestorlang][1]/@filename"/>
    </xsl:variable>

    <!-- Get the translated string -->
    <xsl:variable name="str" select="document($stringfile,document($stringFileList))/strings/str[@name=$stringName]"/>

    <xsl:choose>
        <!-- If the string was found, use it. Cannot test $str, because value could be empty. -->
        <xsl:when test="document($stringfile,document($stringFileList))/strings/str[@name=$stringName]">
            <xsl:value-of select="$str"/>
        </xsl:when>
        <!-- If the current language is not the default language, try the default -->
        <xsl:when test="$ancestorlang!=$DEFAULTLANG">
            <!-- Determine which file holds the defaults; then get the default translation. -->
            <xsl:variable name="backupstringfile">
                <xsl:value-of select="document($stringFileList)/*/lang[@xml:lang=$DEFAULTLANG]/@filename"/>
            </xsl:variable>
            <xsl:variable name="str-default" select="document($backupstringfile,document($stringFileList))/strings/str[@name=$stringName]"/>

            <xsl:choose>
                <!-- If a default was found, use it, but warn that fallback was needed.-->
                <xsl:when test="string-length($str-default)>0">
                    <xsl:value-of select="$str-default"/>
                    <xsl:call-template name="output-message">
                        <xsl:with-param name="msg">No string named '<xsl:value-of select="$stringName"/>' was found for language <xsl:value-of select="$ancestorlang"/>.
Using the default language (<xsl:value-of select="$DEFAULTLANG"/>).</xsl:with-param>
                        <xsl:with-param name="msgnum">008</xsl:with-param>
                        <xsl:with-param name="msgsev">W</xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <!-- Translation was not even found in the default language. -->
                <xsl:otherwise>
                    <xsl:value-of select="$stringName"/>
                    <xsl:call-template name="output-message">
                        <xsl:with-param name="msg">No string named '<xsl:value-of select="$stringName"/>' was found in '<xsl:value-of select="$stringfile"/>' [for <xsl:value-of select="$stringFileList"/>]. Using original value.</xsl:with-param>
                        <xsl:with-param name="msgnum">008</xsl:with-param>
                        <xsl:with-param name="msgsev">W</xsl:with-param>
                    </xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <!-- The current language is the default; no translation found at all. -->
        <xsl:otherwise>
            <xsl:value-of select="$stringName"/>
            <xsl:call-template name="output-message">
                <xsl:with-param name="msg">No string named '<xsl:value-of select="$stringName"/>' was found in '<xsl:value-of select="$stringfile"/>' [for <xsl:value-of select="$stringFileList"/>]. Using original value.</xsl:with-param>
                <xsl:with-param name="msgnum">008</xsl:with-param>
                <xsl:with-param name="msgsev">W</xsl:with-param>
            </xsl:call-template>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


</xsl:stylesheet>
